@@ -25,6 +25,7 @@ from ironic_lib import auth_basic
 from werkzeug import exceptions as wz_exc
 
 from sushy_tools.emulator import api_utils
+from sushy_tools.emulator.controllers import certificate_service as certctl
 from sushy_tools.emulator.controllers import virtual_media as vmctl
 from sushy_tools.emulator import memoize
 from sushy_tools.emulator.resources import chassis as chsdriver
@@ -32,6 +33,7 @@ from sushy_tools.emulator.resources import drives as drvdriver
 from sushy_tools.emulator.resources import indicators as inddriver
 from sushy_tools.emulator.resources import managers as mgrdriver
 from sushy_tools.emulator.resources import storage as stgdriver
+from sushy_tools.emulator.resources.systems import fakedriver
 from sushy_tools.emulator.resources.systems import libvirtdriver
 from sushy_tools.emulator.resources.systems import novadriver
 from sushy_tools.emulator.resources import vmedia as vmddriver
@@ -94,9 +96,14 @@ class Application(flask.Flask):
     @property
     @memoize.memoize()
     def systems(self):
+        fake = self.config.get('SUSHY_EMULATOR_FAKE_DRIVER')
         os_cloud = self.config.get('SUSHY_EMULATOR_OS_CLOUD')
 
-        if os_cloud:
+        if fake:
+            result = fakedriver.FakeDriver.initialize(
+                self.config, self.logger)()
+
+        elif os_cloud:
             if not novadriver.is_loaded:
                 self.logger.error('Nova driver not loaded')
                 sys.exit(1)
@@ -156,6 +163,7 @@ class Application(flask.Flask):
 
 
 app = Application()
+app.register_blueprint(certctl.certificate_service)
 app.register_blueprint(vmctl.virtual_media)
 
 
@@ -361,16 +369,22 @@ def system_resource(identity):
 
         app.logger.debug('Serving resources for system "%s"', identity)
 
+        def try_get(call):
+            try:
+                return call(identity)
+            except error.NotSupportedError:
+                return None
+
         return flask.render_template(
             'system.json',
             identity=identity,
             name=app.systems.name(identity),
             uuid=app.systems.uuid(identity),
             power_state=app.systems.get_power_state(identity),
-            total_memory_gb=app.systems.get_total_memory(identity),
-            total_cpus=app.systems.get_total_cpus(identity),
+            total_memory_gb=try_get(app.systems.get_total_memory),
+            total_cpus=try_get(app.systems.get_total_cpus),
             boot_source_target=app.systems.get_boot_device(identity),
-            boot_source_mode=app.systems.get_boot_mode(identity),
+            boot_source_mode=try_get(app.systems.get_boot_mode),
             managers=app.managers.get_managers_for_system(identity),
             chassis=app.chassis.chassis[:1],
             indicator_led=app.indicators.get_indicator_state(
@@ -761,6 +775,10 @@ def parse_args():
                                     'environment variable '
                                     'SUSHY_EMULATOR_LIBVIRT_URI. '
                                     'Default is qemu:///system')
+    backend_group.add_argument('--fake', action='store_true',
+                               help='Use the fake driver. Can also be set '
+                                    'via environmnet variable '
+                                    'SUSHY_EMULATOR_FAKE_DRIVER.')
 
     return parser.parse_args()
 
@@ -779,6 +797,9 @@ def main():
     if args.libvirt_uri:
         app.config['SUSHY_EMULATOR_LIBVIRT_URI'] = args.libvirt_uri
 
+    if args.fake:
+        app.config['SUSHY_EMULATOR_FAKE_DRIVER'] = True
+
     else:
         for envvar in ('SUSHY_EMULATOR_LIBVIRT_URL',  # backward compatibility
                        'SUSHY_EMULATOR_LIBVIRT_URI'):
