@@ -671,9 +671,9 @@ class StorageTestCase(EmulatorTestCase):
                                  'Volumes', json=data)
 
         self.assertEqual(201, response.status_code)
-        self.assertEqual('http://localhost/redfish/v1/Systems/vmc-node/'
-                         'Storage/1/Volumes/13087010612',
-                         response.headers['Location'])
+        self.assertIn('/redfish/v1/Systems/vmc-node/'
+                      'Storage/1/Volumes/13087010612',
+                      response.headers['Location'])
 
     @patch_resource('volumes')
     def test_volume_resource_get(self, volumes_mock, systems_mock):
